### Name: train
### Title: Fit Predictive Models over Different Tuning Parameters
### Aliases: train train.default train.formula
### Keywords: models

### ** Examples

#######################################
## Classification Example

data(iris)
TrainData <- iris[,1:4]
TrainClasses <- iris[,5]

knnFit1 <- train(TrainData, TrainClasses,
                 "knn",
                 tuneLength = 10,
                 trControl = trainControl(method = "cv"))

knnFit2 <- train(TrainData, TrainClasses,
                 "knn", tuneLength = 10, 
                 trControl = trainControl(method = "boot"))

library(MASS)
nnetFit <- train(TrainData, TrainClasses,
                 "nnet", 
                 tuneLength = 2,
                 trace = FALSE,
                 maxit = 100)

#######################################
## Regression Example

library(mlbench)
data(BostonHousing)

lmFit <- train(medv ~ . + rm:lstat,
               data = BostonHousing, 
               "lm")

library(rpart)
rpartFit <- train(medv ~ .,
                  data = BostonHousing,
                  "rpart",
                  tuneLength = 9)

#######################################
## Example with a custom metric

madSummary <- function (data,
                        lev = NULL,
                        model = NULL) 
{
  out <- mad(data$obs - data$pred, 
             na.rm = TRUE)  
  names(out) <- "MAD"
  out
}

robustControl <- trainControl(summaryFunction = madSummary)
marsGrid <- expand.grid(.degree = 1,
                        .nprune = (1:10) * 2)

earthFit <- train(medv ~ .,
                  data = BostonHousing, 
                  "earth",
                  tuneGrid = marsGrid,
                  metric = "MAD",
                  maximize = FALSE,
                  trControl = robustControl)

#######################################
## Parallel Processing Example via MPI

## Not run: 
##D 
##D ## A function to emulate lapply in parallel
##D mpiClacs <- function(X, FUN, ...)
##D   {
##D     theDots <- list(...)
##D     parLapply(theDots$cl, X, FUN)
##D   }
##D 
##D library(snow)
##D cl <- makeCluster(5, "MPI")
##D 
##D ## 50 bootstrap models distributed across 5 workers
##D mpiControl <- trainControl(workers = 5,
##D                            number = 50,
##D                            computeFunction = mpiClacs,
##D                            computeArgs = list(cl = cl))
##D set.seed(1)
##D usingMPI <-  train(medv ~ .,
##D                    data = BostonHousing, 
##D                    "glmboost",
##D                    trControl = mpiControl)
##D 
##D stopCluster(cl)
## End(Not run)

#######################################
## Parallel Processing Example via NWS
## Not run: 
##D 
##D nwsClacs <- function(X, FUN, ...)
##D   {
##D     theDots <- list(...)
##D     eachElem(theDots$sObj,
##D              fun = FUN,
##D              elementArgs = list(X))
##D   }
##D 
##D library(nws)
##D sObj <- sleigh(workerCount = 5)
##D 
##D nwsControl <- trainControl(workers = 5,
##D                            number = 50,
##D                            computeFunction = nwsClacs,
##D                            computeArgs = list(sObj = sObj))
##D set.seed(1)
##D usingNWS <-  train(medv ~ .,
##D                    data = BostonHousing, 
##D                    "glmboost",
##D                    trControl = nwsControl)
##D 
##D close(sObj)
##D 
## End(Not run)




